@@ -40,12 +40,15 @@
 #'   below.
 #'
 #' @param optmethod A string specifying which optimization function is to be
-#'   used. Options include \code{"nlm"}, \code{"lbfgsb"} (which calls
-#'   \code{optim} with \code{method = "L-BFGS-B"}), and \code{"trust"} (which
-#'   calls into package \code{trust}). Other options are \code{"nohess_nlm"},
+#'   used. Options include \code{"nlm"} (which calls \code{\link[stats]{nlm}}),
+#'   \code{"lbfgsb"} (which calls \code{\link[stats]{optim}}
+#'   with \code{method = "L-BFGS-B"}), and \code{"trust"} (which
+#'   calls into the \code{\link[trust]{trust}} package).
+#'   Other options are \code{"nohess_nlm"},
 #'   \code{"nograd_nlm"}, and \code{"nograd_lbfgsb"}, which use numerical
-#'   approximations rather than exact expressions for the Hessian and (for
-#'   the latter two) the gradient. The default option is \code{"nohess_nlm"}.
+#'   approximations rather than exact expressions for the Hessian; both of the
+#'   \code{"nograd"} functions use numerical approximations for the gradient as
+#'   well. The default option is \code{"nohess_nlm"}.
 #'
 #' @param control A list of control parameters to be passed to the
 #'   optimization function specified by parameter \code{optmethod}.
@@ -158,18 +161,20 @@ ebnm_point_laplace <- function(x,
 
 #' Solve the EBNM problem using point-exponential priors
 #'
-#' Solves the empirical Bayes normal means (EBNM) problem using the family of
-#'   point-exponential priors (the family of mixtures where one component is a
-#'   point mass at \eqn{\mu} and the other is a (nonnegative) exponential
-#'   distribution with mode \eqn{\mu}). Identical to function \code{\link{ebnm}}
-#'   with argument \code{prior_family = "point_exponential"}. For details about
-#'   the model, see \code{\link{ebnm}}.
+#' Solves the empirical Bayes normal means (EBNM) problem using the
+#' family of point-exponential priors (the family of mixtures where
+#' one component is a point mass at \eqn{\mu} and the other is a
+#' (nonnegative) exponential distribution with mode
+#' \eqn{\mu}). Identical to function \code{\link{ebnm}} with argument
+#' \code{prior_family = "point_exponential"}. For details about the
+#' model, see \code{\link{ebnm}}.
 #'
 #' @inherit ebnm_point_normal
 #'
-#' @param scale A scalar specifying the scale parameter of the exponential
-#'   component or \code{"estimate"} if the scale is to be estimated
-#'   from the data.
+#' @param scale A scalar specifying the scale parameter of the
+#'   exponential component or \code{"estimate"} if the scale is to be
+#'   estimated from the data. The mean of the exponential component is
+#'   the same as the value of \code{scale}.
 #'
 #' @param g_init The prior distribution \eqn{g}. Usually this is left
 #'   unspecified (\code{NULL}) and estimated from the data. However, it can be
@@ -352,8 +357,11 @@ ebnm_horseshoe <- function(x,
 #'   \code{\link[ashr]{normalmix}} or an \code{ebnm} object in which the fitted
 #'   prior is an object of class \code{normalmix}.
 #'
-#' @param control A list of control parameters to be passed to optimization
-#'   function \code{\link[mixsqp]{mixsqp}}.
+#' @param optmethod A string specifying which optimization function is to be
+#'   used. Options are provided by package
+#'   \code{ashr}. The default method uses the mix-SQP algorithm implemented in
+#'   the \code{\link[mixsqp]{mixsqp}} package. See the \code{\link[ashr]{ash}} function
+#'   documentation for other options.
 #'
 #' @param ... When parameter \code{gridmult} is set, an
 #'   \code{\link[ashr]{ash}}-style grid will be used instead of the default
@@ -369,6 +377,7 @@ ebnm_normal_scale_mixture <- function(x,
                                       g_init = NULL,
                                       fix_g = FALSE,
                                       output = ebnm_output_default(),
+                                      optmethod = NULL,
                                       control = NULL,
                                       ...) {
   return(ebnm_workhorse(x = x,
@@ -378,7 +387,7 @@ ebnm_normal_scale_mixture <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
-                        optmethod = NULL,
+                        optmethod = optmethod,
                         control = control,
                         prior_family = "normal_scale_mixture",
                         call = match.call(),
@@ -434,6 +443,7 @@ ebnm_unimodal <- function(x,
                           g_init = NULL,
                           fix_g = FALSE,
                           output = ebnm_output_default(),
+                          optmethod = NULL,
                           control = NULL,
                           ...) {
   return(ebnm_workhorse(x = x,
@@ -443,7 +453,7 @@ ebnm_unimodal <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
-                        optmethod = NULL,
+                        optmethod = optmethod,
                         control = control,
                         prior_family = "unimodal",
                         call = match.call(),
@@ -485,6 +495,7 @@ ebnm_unimodal_symmetric <- function(x,
                                     g_init = NULL,
                                     fix_g = FALSE,
                                     output = ebnm_output_default(),
+                                    optmethod = NULL,
                                     control = NULL,
                                     ...) {
   return(ebnm_workhorse(x = x,
@@ -494,7 +505,7 @@ ebnm_unimodal_symmetric <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
-                        optmethod = NULL,
+                        optmethod = optmethod,
                         control = control,
                         prior_family = "unimodal_symmetric",
                         call = match.call(),
@@ -537,6 +548,7 @@ ebnm_unimodal_nonnegative <- function(x,
                                       g_init = NULL,
                                       fix_g = FALSE,
                                       output = ebnm_output_default(),
+                                      optmethod = NULL,
                                       control = NULL,
                                       ...) {
   return(ebnm_workhorse(x = x,
@@ -546,7 +558,7 @@ ebnm_unimodal_nonnegative <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
-                        optmethod = NULL,
+                        optmethod = optmethod,
                         control = control,
                         prior_family = "unimodal_nonnegative",
                         call = match.call(),
@@ -589,6 +601,7 @@ ebnm_unimodal_nonpositive <- function(x,
                                       g_init = NULL,
                                       fix_g = FALSE,
                                       output = ebnm_output_default(),
+                                      optmethod = NULL,
                                       control = NULL,
                                       ...) {
   return(ebnm_workhorse(x = x,
@@ -598,7 +611,7 @@ ebnm_unimodal_nonpositive <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
-                        optmethod = NULL,
+                        optmethod = optmethod,
                         control = control,
                         prior_family = "unimodal_nonpositive",
                         call = match.call(),
@@ -640,8 +653,7 @@ ebnm_unimodal_nonpositive <- function(x,
 #'   prior is an object of class \code{tnormalmix}.
 #'
 #' @param control A list of control parameters to be passed to function
-#'   \code{\link[stats]{optim}}, where \code{method} has been set to
-#'   \code{"L-BFGS-B"}.
+#'   \code{\link[stats]{optimize}}.
 #'
 #' @param ... The following additional arguments act as control parameters for
 #'   the outer EM loops in the fitting algorithm. Each loop iteratively updates
@@ -665,10 +677,11 @@ ebnm_unimodal_nonpositive <- function(x,
 #'      }
 #'
 #' @references
-#' Yusha Liu, Peter Carbonetto, Jason Willwerscheid, Scott A Oakes, Kay F Macleod,
-#'   and Matthew Stephens (2023). Dissecting tumor transcriptional heterogeneity
-#'   from single-cell RNA-seq data by generalized binary covariance decomposition.
-#'   bioRxiv 2023.08.15.553436.
+#' Yusha Liu, Peter Carbonetto, Jason Willwerscheid, Scott A Oakes,
+#'   Kay F Macleod, and Matthew Stephens (2025). Dissecting tumor
+#'   transcriptional heterogeneity from single-cell RNA-seq data by
+#'   generalized binary covariance decomposition.  \emph{Nature Genetics}
+#'   \strong{57}, 263--273. \doi{doi:10.1038/s41588-024-01997-z}.
 #'
 #' @export
 #'
@@ -681,6 +694,10 @@ ebnm_generalized_binary <- function(x,
                                     output = ebnm_output_default(),
                                     control = NULL,
                                     ...) {
+  if ("optmethod" %in% names(list(...))) {
+    stop("optmethod parameter is not used by ebnm_generalized_binary.")
+  }
+
   return(ebnm_workhorse(x = x,
                         s = s,
                         mode = mode,
@@ -728,7 +745,17 @@ ebnm_generalized_binary <- function(x,
 #'   or an \code{ebnm} object in which the fitted
 #'   prior is an object of class \code{normalmix}.
 #'
-#' @param optmethod Not used by \code{ebnm_npmle}.
+#' @param optmethod A string specifying which optimization function is to be
+#'   used. Options are provided by package
+#'   \code{ashr}. The default method uses the mix-SQP algorithm implemented in
+#'   the \code{mixsqp} package. See the \code{\link[ashr]{ash}} function
+#'   documentation for other options. It is also possible to
+#'   specify \code{optmethod = "REBayes"}, which uses function
+#'   \code{\link[REBayes]{GLmix}} in the \code{REBayes} package
+#'   to estimate the NPMLE rather than \code{ashr}. Note that \code{REBayes}
+#'   requires installation of the commercial interior-point solver MOSEK; for
+#'   details, see \code{\link[REBayes]{KWDual}} (the core optimization routine
+#'   for the \code{REBayes} package).
 #'
 #' @export
 #'
@@ -838,6 +865,7 @@ ebnm_flat <- function(x,
                         g_init = g_init,
                         fix_g = fix_g,
                         output = output,
+                        optmethod = NULL,
                         control = NULL,
                         prior_family = "flat",
                         call = match.call()))
@@ -866,6 +894,9 @@ ebnm_flat <- function(x,
 #'   \code{\link[ashr]{normalmix}} or an \code{ebnm} object in which the fitted
 #'   prior is an object of class \code{normalmix}.
 #'
+#' @param control A list of control parameters to be passed to function
+#'   \code{\link[stats]{optimize}}.
+#'
 #' @export
 #'
 ebnm_point_mass <- function(x,
@@ -873,7 +904,8 @@ ebnm_point_mass <- function(x,
                             mode = 0,
                             g_init = NULL,
                             fix_g = FALSE,
-                            output = ebnm_output_default()) {
+                            output = ebnm_output_default(),
+                            control = NULL) {
   return(ebnm_workhorse(x = x,
                         s = s,
                         mode = mode,
