@@ -6,7 +6,7 @@ s <- rgamma(50, 1, 1)
 x <- mu + rnorm(50, 0, s)
 
 test_that("point-normal sampler gives reasonable results", {
-  res <- ebnm_point_normal(x, s, output = output_all())
+  res <- ebnm_point_normal(x, s, output = ebnm_output_all())
   samp <- res$posterior_sampler(1000)
 
   expect_equal(colMeans(samp), res[[df_ret_str()]][[pm_ret_str()]], tol = 0.1)
@@ -14,7 +14,7 @@ test_that("point-normal sampler gives reasonable results", {
 })
 
 test_that("point-Laplace sampler gives reasonable results", {
-  res <- ebnm_point_laplace(x, s, output = output_all())
+  res <- ebnm_point_laplace(x, s, output = ebnm_output_all())
   samp <- res$posterior_sampler(1000)
 
   expect_equal(colMeans(samp), res[[df_ret_str()]][[pm_ret_str()]], tol = 0.1)
@@ -22,7 +22,7 @@ test_that("point-Laplace sampler gives reasonable results", {
 })
 
 test_that("point-exponential sampler gives reasonable results", {
-  res <- ebnm_point_exponential(x, s, output = output_all())
+  res <- ebnm_point_exponential(x, s, output = ebnm_output_all())
   samp <- res$posterior_sampler(1000)
 
   expect_equal(colMeans(samp), res[[df_ret_str()]][[pm_ret_str()]], tol = 0.1)
@@ -30,7 +30,7 @@ test_that("point-exponential sampler gives reasonable results", {
 })
 
 test_that("normal-mixture sampler gives reasonable results", {
-  res <- ebnm_normal_scale_mixture(x, s, output = output_all())
+  res <- ebnm_normal_scale_mixture(x, s, output = ebnm_output_all())
   samp <- res$posterior_sampler(1000)
 
   expect_equal(colMeans(samp), res[[df_ret_str()]][[pm_ret_str()]], tol = 0.1)
